.. latest documentation master file, created by
   sphinx-quickstart on Tue Jul 18 11:02:33 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to latest
=================

``latest`` | *A* :math:`\LaTeX`-*oriented template engine*

:mod:`latest` is lightweight templating engine for Python,
designed for model documents separating the presentation from the data.
It has a simple, configurable, :math:`\LaTeX`-compatible syntax.

.. literalinclude:: ../test/res/lightweight.tmpl
   :language: latex


Features
--------

* command line tool
* :math:`\LaTeX`-compatible
* configurable syntax


Documentation
=============


.. toctree::
   :maxdepth: 2

   source/install
   source/gettingstarted
   source/help
   source/license
   source/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
